.. _irf-edisp:

Energy dispersion
=================

TODO: describe / illustrate the existing classes:

* `~gammapy.irf.EnergyDispersion`
* `~gammapy.irf.EnergyDispersion2D`

.. plot:: irf/plot_edisp.py
